Evolution Strategy Library
=======================================================

ESTorch is an Evolution Strategy Library build around PyTorch.

## Installation

```bash
pip install estorch
```

## Documentation

https://estorch.readthedocs.io/

## Usage

Please refer to [examples](https://github.com/goktug97/estorch/blob/master/examples)

## License
estorch is licensed under the MIT License.

